@@ -488,15 +488,18 @@ class DataTransformerForm(BaseInlineFormSet):
 
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
-        dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
-                                                             fk_name='parent',
-                                                             extra=1, form=DataTransform
-                                                             )
-        form.nested_data_transformer_form = dataTransformerInlineFormset(
-            instance=form.instance,
-            data=form.data if form.is_bound else None,
-            files=form.files if form.is_bound else None
-        )
+
+        if form.instance._state.adding == False:
+            dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
+                                                                 fk_name='parent',
+                                                                 extra=1, form=DataTransform
+                                                                 )
+            form.nested_data_transformer_form = dataTransformerInlineFormset(
+                instance=form.instance,
+                data=form.data if form.is_bound else None,
+                files=form.files if form.is_bound else None
+            )
+
 
 
         form.nested_constants_form = DataConstantsTransformerInlineFormset(
